==> sufary_2.1b3.orig.tar.gz: sufary-2.1b3.orig/perl/SUFARY/setup.sh <==
#!/bin/sh

dlink='y'
sufary='y'
current=`pwd`
str_current=`echo $current | sed 's/\//\\\\\//g' `

cat << 'EOM'
-----------------------------------------------------------
                --- SUFARY Perl Module ---

ΥץȤϡPerl(ver.5ʾ)  SUFARY 
Ȥ⥸塼򥻥åȥåפΤǤ
-----------------------------------------------------------
EOM
echo -n "åȥåפޤ [n]: "
read ans
case "$ans" in
y*)
	echo "ǤϼǤ ..."
	;;
*)
	echo "Ȥޤ ..."
	kill $$
	;;
esac

cat << 'EOM'
-----------------------------------------------------------
Perl ver.5 ʾ夬ɬפǤɤ˥󥹥ȡ뤵Ƥ
ޤ եѥ̾Ʋ
-----------------------------------------------------------
EOM
jperl=`which perl`
if test -x "$jperl"; then
	echo -n
else
	jperl='perl'
fi
str_jperl=''
while test "$str_jperl" = "" ; do
	echo -n "? [$jperl]: "
	read ans
	case "$ans" in
	'')
		if test -r "$jperl"; then
			echo "ok."
			str_jperl=`echo $jperl | sed 's/\//\\\\\//g' `
		fi
		;;
	*)
		if test -r "$ans"; then
			echo "λ"
			jperl=$ans
			str_jperl=`echo $jperl | sed 's/\//\\\\\//g' `
		else
			echo "դޤ " $ans
		fi
		;;
	esac
done

cat << 'EOM'
-----------------------------------------------------------
ʥߥå󥯥饤֥(libsufary.so.*)Ѥޤ
No 򤷤 libsufary.a Ѥޤ
-----------------------------------------------------------
EOM
echo -n "ʥߥå󥯥饤֥λ [y]: "
read ans
case "$ans" in
n*)
	dlink='n'
	;;
*)
	dlink='y'
	;;
esac

echo -----------------------------------------------------------
echo Perl = $jperl
echo ʥߥå󥯥饤֥λ = $dlink
echo ȥǥ쥯ȥ = 
echo "	$current"
echo -----------------------------------------------------------

echo -n "ǤǤ [y]: "
read ans
case "$ans" in
	n*)
		echo 
		exit
		;;
esac

# sufary
echo "----- SUFARY module  -----"
case "$dlink" in
y*)
	$jperl ./Makefile.PL
	;;
*)
	$jperl ./Makefile.static.PL
	;;
esac
make

# sgrep
echo "--------- sgrep  ----------"
cat ./sgrep.org | sed 's/^#!.*$/#!'$str_jperl'/' | sed 's/SUFARY_LIB = \".*\"/SUFARY_LIB = \"'$str_current'\"/' > ./sgrep
chmod +x ./sgrep
echo "---------------------------------"

echo λޤ
#echo    $jperl ./test.perl
#echo ǥƥȤǤޤ

echo

==> sufary_2.1.1.orig.tar.gz: sufary-2.1.1/perl/SUFARY/setup.sh <==
#!/bin/sh

dlink='y'
sufary='y'
current=`pwd`
str_current=`echo $current | sed 's/\//\\\\\//g' `

cat << 'EOM'
-----------------------------------------------------------
                --- SUFARY Perl Module ---

ΥץȤϡPerl(ver.5ʾ)  SUFARY 
Ȥ⥸塼򥻥åȥåפΤǤ
-----------------------------------------------------------
EOM
echo -n "åȥåפޤ [n]: "
read ans
case "$ans" in
y*)
	echo "ǤϼǤ ..."
	;;
*)
	echo "Ȥޤ ..."
	kill $$
	;;
esac

cat << 'EOM'
-----------------------------------------------------------
Perl ver.5 ʾ夬ɬפǤɤ˥󥹥ȡ뤵Ƥ
ޤ եѥ̾Ʋ
-----------------------------------------------------------
EOM
jperl=`which perl`
if test -x "$jperl"; then
	echo -n
else
	jperl='perl'
fi
str_jperl=''
while test "$str_jperl" = "" ; do
	echo -n "? [$jperl]: "
	read ans
	case "$ans" in
	'')
		if test -r "$jperl"; then
			echo "ok."
			str_jperl=`echo $jperl | sed 's/\//\\\\\//g' `
		fi
		;;
	*)
		if test -r "$ans"; then
			echo "λ"
			jperl=$ans
			str_jperl=`echo $jperl | sed 's/\//\\\\\//g' `
		else
			echo "դޤ " $ans
		fi
		;;
	esac
done

cat << 'EOM'
-----------------------------------------------------------
ʥߥå󥯥饤֥(libsufary.so.*)Ѥޤ
No 򤷤 libsufary.a Ѥޤ
-----------------------------------------------------------
EOM
echo -n "ʥߥå󥯥饤֥λ [n]: "
read ans
case "$ans" in
y*)
	dlink='y'
	;;
*)
	dlink='n'
	;;
esac

echo -----------------------------------------------------------
echo Perl = $jperl
echo ʥߥå󥯥饤֥λ = $dlink
echo ȥǥ쥯ȥ = 
echo "	$current"
echo -----------------------------------------------------------

echo -n "ǤǤ [y]: "
read ans
case "$ans" in
	n*)
		echo 
		exit
		;;
esac

# sufary
echo "----- SUFARY module  -----"
case "$dlink" in
y*)
	$jperl ./Makefile.PL
	;;
*)
	$jperl ./Makefile.static.PL
	;;
esac
make

# sgrep
echo "--------- sgrep  ----------"
cat ./sgrep.org | sed 's/^#!.*$/#!'$str_jperl'/' | sed 's/SUFARY_LIB = \".*\"/SUFARY_LIB = \"'$str_current'\"/' > ./sgrep
chmod +x ./sgrep
echo "---------------------------------"

echo λޤ
#echo    $jperl ./test.perl
#echo ǥƥȤǤޤ

echo
